@@ -5,33 +5,33 @@
 # all_traits_features.py --- Shows primary features of the Traits
 #                            package
 
-#--[Imports]--------------------------------------------------------------------
+#--[Imports]-------------------------------------------------------------------
 from traits.api import Delegate, HasTraits, Instance, Int, Str
 
-#--[Code]-----------------------------------------------------------------------
-# Shows the five primary features of the Traits package.
 
-class Parent ( HasTraits ):
+#--[Code]----------------------------------------------------------------------
+# Shows the five primary features of the Traits package.
+class Parent(HasTraits):
 
     # INITIALIZATION: last_name' is initialized to '':
-    last_name = Str( '' )
+    last_name = Str('')
 
 
-class Child ( HasTraits ):
+class Child(HasTraits):
 
     age = Int
 
     # VALIDATION: 'father' must be a Parent instance:
-    father = Instance( Parent )
+    father = Instance(Parent)
 
     # DELEGATION: 'last_name' is delegated to father's 'last_name':
-    last_name = Delegate( 'father' )
+    last_name = Delegate('father')
 
     # NOTIFICATION: This method is called when 'age' changes:
-    def _age_changed ( self, old, new ):
-        print 'Age changed from %s to %s ' % ( old, new )
+    def _age_changed(self, old, new):
+        print 'Age changed from %s to %s ' % (old, new)
 
-#--[Example*]-------------------------------------------------------------------
+#--[Example*]------------------------------------------------------------------
 
 # Set up the example:
 joe = Parent()
@@ -52,4 +52,3 @@ moe.age = 10
 # VISUALIZATION: Displays a UI for editing moe's
 # attributes (if a supported GUI toolkit is installed)
 moe.configure_traits()
-
