@@ -3,12 +3,12 @@
 
 # object_trait_attrs.py --- Example of per-object trait attributes
 
-#--[Imports]--------------------------------------------------------------------
+#--[Imports]-------------------------------------------------------------------
 from traits.api import HasTraits, Range
 
-#--[Code]-----------------------------------------------------------------------
 
-class GUISlider (HasTraits):
+#--[Code]----------------------------------------------------------------------
+class GUISlider(HasTraits):
 
     def __init__(self, eval=None, label='Value',
                  trait=None, min=0.0, max=1.0,
@@ -20,9 +20,6 @@ class GUISlider (HasTraits):
             if initial is None:
                 initial = min
             elif not (min <= initial <= max):
-                initial = [min, max][
-                            abs(initial - min) >
-                            abs(initial - max)]
-            trait = Range(min, max, value = initial)
+                initial = [min, max][abs(initial - min) > abs(initial - max)]
+            trait = Range(min, max, value=initial)
         self.add_trait(label, trait)
-
