@@ -1,7 +1,7 @@
 #  Copyright (c) 2007, Enthought, Inc.
 #  License: BSD Style.
 
-#--(__getstate__/__setstate__ Changes and Improvements)-------------------------
+#--(__getstate__/__setstate__ Changes and Improvements)------------------------
 """
 __getstate__/__setstate__ Changes and Improvements
 ==================================================
@@ -35,34 +35,34 @@ eliminating the need to override or define a *__getstate__* method in their
 application classes.
 
 In particular, the **HasTraits** *__getstate__* method saves the value of all
-traits which do not have *transient = True* metadata defined. This policy allows
-developers to easily mark which trait values should not be saved simply by
-adding *transient = True* metadata to them. Besides avoiding having to write a
-*__getstate__* method for their class, this approach also provides good
-documentation about the *pickling* behavior of the class.
+traits which do not have *transient = True* metadata defined. This policy
+allows developers to easily mark which trait values should not be saved simply
+by adding *transient = True* metadata to them. Besides avoiding having to
+write a *__getstate__* method for their class, this approach also provides
+good documentation about the *pickling* behavior of the class.
 
 For example::
 
-    class DataBase ( HasTraits ):
+    class DataBase(HasTraits):
 
         # The name of the data base file:
         file_name = File
 
         # The open file handle used to access the data base:
-        file = Any( transient = True )
+        file = Any(transient = True)
 
 In this example, the **DataBase** class's *file* trait has been mark as
 *transient* because it normally contains an open file handle used to access a
-data base. Since file handles typically cannot be pickled and restored, the file
-handle should not be saved as part of the object's persistent state. Normally,
-the file handle would be re-opened by application code after the object has been
-restored from its persisted state.
+data base. Since file handles typically cannot be pickled and restored, the
+file handle should not be saved as part of the object's persistent state.
+Normally, the file handle would be re-opened by application code after the
+object has been restored from its persisted state.
 
 Predefined *transient* Traits
 -----------------------------
 
-The Traits package automatically assigns *transient = True* metadata to a number
-of predefined traits, thus avoiding the need to explicitly mark them as
+The Traits package automatically assigns *transient = True* metadata to a
+number of predefined traits, thus avoiding the need to explicitly mark them as
 transient yourself.
 
 The predefined traits marked as *transient* are:
@@ -74,9 +74,8 @@ The predefined traits marked as *transient* are:
 - All *_xxx* traits for classes that subclass **HasPrivateTraits**.
 
 Also, by default, delegated traits are only saved if they have a local value
-which overrides the value defined by its delegate. You can set
-*transient = True* on the delegate trait if you do not want its value to ever be
-saved.
+which overrides the value defined by its delegate. You can set *transient =
+True* on the delegate trait if you do not want its value to ever be saved.
 
 Overriding *__getstate__*
 -------------------------
@@ -89,8 +88,8 @@ However, in cases where this strategy is insufficient, we recommend
 overriding *__getstate__* using the follow pattern to remove items that should
 not be persisted::
 
-    def __getstate__ ( self ):
-        state = super( XXX, self ).__getstate__()
+    def __getstate__(self):
+        state = super(XXX, self).__getstate__()
 
         for key in [ 'foo', 'bar' ]:
             if key in state:
@@ -107,8 +106,8 @@ the new **HasTraits** class *__setstate__* method is that the **HasTraits**
 passed to it via its state dictionary argument instead of simply storing or
 copying the state dictionary to its *__dict__* attribute.
 
-While slower, this has the advantage of causing trait change notifications to be
-generated, which can be very useful for classes which rely of receiving
+While slower, this has the advantage of causing trait change notifications to
+be generated, which can be very useful for classes which rely of receiving
 notifications in order to ensure that their internal object state remains
 consistent and up to date.
 
@@ -128,54 +127,48 @@ notifications managed by traits are correctly initialized for the object.
 Failure to call this method may result in lost change notifications.
 """
 
-#--<Imports>--------------------------------------------------------------------
-
 from traits.api import *
-
 from time import time, sleep
-
 from cPickle import dumps, loads
 
-#--[Session Class]--------------------------------------------------------------
 
-class Session ( HasTraits ):
+#--[Session Class]-------------------------------------------------------------
+class Session(HasTraits):
 
     # The name of the session:
     name = Str
 
     # The time the session was created:
-    created = Any( transient = True )
+    created = Any(transient=True)
 
-    def _name_changed ( self ):
+    def _name_changed(self):
         self.created = time()
 
-#--[Example*]-------------------------------------------------------------------
+#--[Example*]------------------------------------------------------------------
 
 # The following shows an example of pickling and unpickling a Session object.
 # Unfortunately, it is not possible to successfully pickle objects created as
 # part of a tutorial, because of problems with pickling objects derived from
-# classes dynamically defined using 'exec'. So just use your imagination on this
-# one...
+# classes dynamically defined using 'exec'. So just use your imagination on
+# this one...
 
 # Create a new session:
-session = Session( name = 'session_1' )
+session = Session(name='session_1')
 
 # Display its contents:
-print 'Session name:',    session.name
+print 'Session name:', session.name
 print 'Session created:', session.created
 
 # # Simulate saving the session to a file/database:
-# saved_session = dumps( session )
+# saved_session = dumps(session)
 #
 # # Simulate the passage of time (zzzzZZZZ...):
-# sleep( 1 )
+# sleep(1)
 #
 # # Simulate restoring the session from a file/database:
-# restored_session = loads( saved_session )
+# restored_session = loads(saved_session)
 #
 # # Display the restored sessions contents (note that the 'created'
 # # time should be different from the original session):
 # print 'Restored session name:',    restored_session.name
 # print 'Restored session created:', restored_session.created
-
-
