@@ -1,7 +1,7 @@
 #  Copyright (c) 2007, Enthought, Inc.
 #  License: BSD Style.
 
-#--(Adaptation)-----------------------------------------------------------------
+#--(Adaptation)----------------------------------------------------------------
 """
 Adaptation
 ==========
@@ -22,9 +22,9 @@ the simplest way, which is to create a subclass of **Adapter**.
 Subclassing Adapter
 -------------------
 
-The **Adapter** base class is designed specifically for creating adapter classes.
-It is actually a very simple class which streamlines the process of creating
-new adapter classes by:
+The **Adapter** base class is designed specifically for creating adapter
+classes. It is actually a very simple class which streamlines the process of
+creating new adapter classes by:
 
 - Providing a standard constructor which normally does not need to be
   overridden by subclasses.
@@ -33,7 +33,7 @@ new adapter classes by:
 
 The standard constructor for the **Adapter** class has the form::
 
-    adapter_subclass_name( object_to_be_adapted )
+    adapter_subclass_name(object_to_be_adapted)
 
 where *adapter_subclass_name* is the name of the **Adapter** subclass.
 
@@ -43,15 +43,15 @@ The only thing the constructor does is::
 
 which assigns the object being adapted to the *adaptee* trait.
 
-As an adapter writer, the only things you need to add to the subclass definition
-are:
+As an adapter writer, the only things you need to add to the subclass
+definition are:
 
 - An **adapts** function call declaring which interfaces the adapter class
   implements on behalf of the object it is adapting.
 
   The form of the **adapts** function is as follows::
 
-    adapts( client_class, interface [, interface2, ..., interfacen] )
+    adapts(client_class, interface [, interface2, ..., interfacen])
 
 - A declaration for the *adaptee* trait (usually as an **Instance** of a
   particular class).
@@ -64,17 +64,17 @@ The following shows the definition of a simple adapter class::
 
   from traits.api import Adapter, Instance, implements
 
-  class PersonINameAdapter ( Adapter ):
+  class PersonINameAdapter (Adapter):
 
       # Declare what interfaces this adapter implements for its client:
-      adapts( Person, IName )
+      adapts(Person, IName)
 
       # Declare the type of client it supports:
-      adaptee = Instance( Person )
+      adaptee = Instance(Person)
 
       # Implement the 'IName' interface on behalf of its client:
-      def get_name ( self ):
-          return ('%s %s' % ( self.adaptee.first_name, self.adaptee.last_name ))
+      def get_name (self):
+          return ('%s %s' % (self.adaptee.first_name, self.adaptee.last_name))
 
 Rolling You Own Adapter Classes
 -------------------------------
@@ -95,21 +95,21 @@ example as follows::
 
   from traits.api import HasTraits, Instance, adapts
 
-  class PersonINameAdapter ( HasTraits ):
+  class PersonINameAdapter(HasTraits):
 
       # Declare what interfaces this adapter implements, and for who:
-      adapts( Person, IName )
+      adapts(Person, IName)
 
       # Declare the type of client it supports:
-      client = Instance( Person )
+      client = Instance(Person)
 
       # Implement the adapter's constructor:
-      def __init__ ( self, client ):
+      def __init__ (self, client):
           self.client = client
 
       # Implement the 'IName' interface on behalf of its client:
-      def get_name ( self ):
-          return ('%s %s' % ( self.client.first_name, self.client.last_name ))
+      def get_name (self):
+          return ('%s %s' % (self.client.first_name, self.client.last_name))
 
 As you can see, the main difference between this example and the last is:
 
@@ -121,23 +121,24 @@ Yet Another Way To Define Adapters
 It is also possible to declare a class to be an adapter class external to the
 class definition itself, as shown in the following example::
 
-    class AnotherPersonAdapter ( object ):
+    class AnotherPersonAdapter (object):
 
         # Implement the adapter's constructor:
-        def __init__ ( self, person ):
+        def __init__ (self, person):
             self.person = person
 
         # Implement the 'IName' interface on behalf of its client:
-        def get_name ( self ):
-            return ('%s %s' % ( self.person.first_name, self.person.last_name ))
+        def get_name (self):
+            return ('%s %s' % (self.person.first_name, self.person.last_name))
 
     ...
 
-    adapts( AnotherPersonAdapter, Person, IName )
+    adapts(AnotherPersonAdapter, Person, IName)
 
 When used in this way, the form of the **adapts** function is::
 
-    adapts( adapter_class, client_class, interface [, interface2, ..., interfacen] )
+    adapts(adapter_class, client_class, interface [, interface2, ...,
+           interfacen])
 
 This form simply inserts the adapter class as the first argument (when
 **adapts** is used inside of a class definition, this information is implicitly
@@ -151,23 +152,24 @@ Now for the good part... how do you use adapters?
 And the answer is... you don't. At least not explicitly.
 
 In traits, adapters are created automatically whenever you assign an object to
-an *interface* **AdaptsTo** or **AdaptedTo** trait and the object being assigned
-does not implement the required interface. In this case, if an adapter class
-exists that can adapt the specified object to the required interface, an
-instance of the adapter class will be created for the object, and the resulting
-adapter object is what ends up being assigned to the trait, along with the
-original object. When using the **AdaptedTo** trait, the adapter is assigned as
-the value of the trait, and the original object is assigned as its *mapped*
-value. For the **AdaptsTo** trait, the original object is assigned as the trait
-value, and the adapter is assigned as its *mapped* value. In the case where the
-object does not require an adapter, the object and adapted value are the same.
+an *interface* **AdaptsTo** or **AdaptedTo** trait and the object being
+assigned does not implement the required interface. In this case, if an
+adapter class exists that can adapt the specified object to the required
+interface, an instance of the adapter class will be created for the object,
+and the resulting adapter object is what ends up being assigned to the trait,
+along with the original object. When using the **AdaptedTo** trait, the
+adapter is assigned as the value of the trait, and the original object is
+assigned as its *mapped* value. For the **AdaptsTo** trait, the original
+object is assigned as the trait value, and the adapter is assigned as its
+*mapped* value. In the case where the object does not require an adapter, the
+object and adapted value are the same.
 
 Note that it might happen that no adapter class exists that will adapt the
 object to the required interface, but a pair, or series, of adapter classes
-exist that will together adapt the object to the needed interface. In this case,
-the required set of adapters will automatically be created for the object and
-the final link in the chain adapter object (the one that actually implements
-the required interface for some object class) will be used.
+exist that will together adapt the object to the needed interface. In this
+case, the required set of adapters will automatically be created for the
+object and the final link in the chain adapter object (the one that actually
+implements the required interface for some object class) will be used.
 
 Whenever a situation like this arises, the adapted object used will always
 contain the smallest set of available adapter objects needed to adapt the
@@ -176,12 +178,12 @@ original object.
 The following code shows a simple example of using adaptation::
 
     # Create a Person object (which does not implement the 'IName' interface):
-    william = Person( first_name = 'William', last_name = 'Adams' )
+    william = Person(first_name = 'William', last_name = 'Adams')
 
     # Create an apartment, and assign 'renter' the previous object. Since
     # the value of 'renter' must implement 'IName', a 'PersonINameAdapter'
     # object is automatically created and assigned:
-    apt = Apartment( renter = william )
+    apt = Apartment(renter = william)
 
     # Verify that the resulting value implements 'IName' correctly:
     print 'Renter is: ', apt.renter.get_name()
@@ -215,67 +217,66 @@ default
 As an example of modifying the adaptation behavior of an **AdaptedTo** trait,
 we could rewrite the example **Apartment** class as follows::
 
-    class Apartment ( HasTraits ):
+    class Apartment(HasTraits):
 
-        renter = AdaptedTo( IName, adapt = 'no' )
+        renter = AdaptedTo(IName, adapt = 'no')
 
 Using this definition, any value assigned to *renter* must itself implement
 the **IName** interface, otherwise an exception is raised. Try modifying and
 re-running the example code to verify that this is indeed the case.
 """
 
-#--<Imports>--------------------------------------------------------------------
+#--<Imports>-------------------------------------------------------------------
 
 from traits.api import *
 
-#--[IName Interface]------------------------------------------------------------
 
+#--[IName Interface]-----------------------------------------------------------
 # Define the 'IName' interface:
-class IName ( Interface ):
+class IName (Interface):
 
-    def get_name ( self ):
+    def get_name(self):
         """ Returns the name of an object. """
 
-#--[Person Class]---------------------------------------------------------------
 
-class Person ( HasTraits ):
+#--[Person Class]--------------------------------------------------------------
+class Person(HasTraits):
 
-    first_name = Str( 'John' )
-    last_name  = Str( 'Doe' )
+    first_name = Str('John')
+    last_name = Str('Doe')
 
-#--[PersonINameAdapter Class]---------------------------------------------------
 
-class PersonINameAdapter ( Adapter ):
+#--[PersonINameAdapter Class]--------------------------------------------------
+class PersonINameAdapter(Adapter):
 
     # Declare what interfaces this adapter implements for its client:
-    adapts( Person, IName )
+    adapts(Person, IName)
 
     # Declare the type of client it supports:
-    adaptee = Instance( Person )
+    adaptee = Instance(Person)
 
     # Implementation of the 'IName' interface on behalf of its client:
-    def get_name ( self ):
+    def get_name(self):
         """ Returns the name of an object. """
-        return ('%s %s' % ( self.adaptee.first_name, self.adaptee.last_name ))
+        return ('%s %s' % (self.adaptee.first_name, self.adaptee.last_name))
 
-#--[Apartment Class]------------------------------------------------------------
 
+#--[Apartment Class]-----------------------------------------------------------
 # Define a class using an object that implements the 'IName' interface:
-class Apartment ( HasTraits ):
+class Apartment(HasTraits):
 
-    renter = AdaptedTo( IName )
+    renter = AdaptedTo(IName)
 
-#--[Example*]--------------------------------------------------------------------
 
+#--[Example*]------------------------------------------------------------------
 # Create an object implementing the 'IName' interface:
-william = Person( first_name = 'William', last_name = 'Adams' )
+william = Person(first_name='William', last_name='Adams')
 
 # Create an apartment, and assign 'renter' an object implementing 'IName':
-apt = Apartment( renter = william )
+apt = Apartment(renter=william)
 
 # Verify that the object works correctly:
 print 'Renter is:', apt.renter.get_name()
 
 # Check the type of object actually assigned to 'renter':
 print apt.renter
-
